@@ -96,7 +96,7 @@ class ScrapyPlaywrightDownloadHandler(HTTPDownloadHandler):
 
         # contexts
         self.static_context_kwargs: dict = settings.getdict("PLAYWRIGHT_STATIC_CONTEXT")
-        self.dynamic_contexts_kwargs: [dict] = settings.getdict("PLAYWRIGHT_DYNAMIC_CONTEXTS") or []
+        self.dynamic_contexts_kwargs: [dict] = settings.getlist("PLAYWRIGHT_DYNAMIC_CONTEXTS") or []
         self.context_semaphore: asyncio.Semaphore = asyncio.Semaphore(value=1)
 
         self.default_navigation_timeout: Optional[float] = None
